@@ -1,4 +1,4 @@
-/* Copyright (c) 2009, 2011, Oracle and/or its affiliates. All rights reserved.
+/* Copyright (c) 2009, 2013, Oracle and/or its affiliates. All rights reserved.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -290,6 +290,7 @@
 /* #undef HAVE_THR_YIELD */
 #define HAVE_TIME 1
 #define HAVE_TIMES 1
+/* #undef HAVE_UCONTEXT */
 #define HAVE_VALLOC 1
 #define HAVE_VIDATTR 1
 #define HAVE_VIO_READ_BUFF 1
@@ -599,7 +600,7 @@
 #define WITH_MYISAMMRG_STORAGE_ENGINE 1
 #define WITH_HEAP_STORAGE_ENGINE 1
 #define WITH_INNOBASE_STORAGE_ENGINE 1
-/* #undef WITH_XTRADB_STORAGE_ENGINE */
+#define WITH_XTRADB_STORAGE_ENGINE 1
 #define WITH_CSV_STORAGE_ENGINE 1
 #define WITH_PARTITION_STORAGE_ENGINE 1
 #define WITH_PERFSCHEMA_STORAGE_ENGINE 1
@@ -617,23 +618,25 @@
 #define DEFAULT_CHARSET_HOME "/usr/local/mysql"
 #define PLUGINDIR "/usr/local/mysql/lib/plugin"
 /* #undef DEFAULT_SYSCONFDIR */
+#define DEFAULT_TMPDIR P_tmpdir
 
 /* #undef SO_EXT */
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 0
-#define MYSQL_VERSION_PATCH 2
+#define MYSQL_VERSION_PATCH 9
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.0.2"
+#define PACKAGE_STRING "MySQL Server 10.0.9"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.0.2"
-#define VERSION "10.0.2"
+#define PACKAGE_VERSION "10.0.9"
+#define VERSION "10.0.9"
 #define PROTOCOL_VERSION 10
 
+#define MALLOC_LIBRARY "bundled jemalloc"
 
 /* time_t related defines */
 
